@@ -19,7 +19,6 @@ from sphinxcontrib.bibtex.nodes import bibliography
 from sphinxcontrib.bibtex.roles import CiteRole
 from sphinxcontrib.bibtex.directives import BibliographyDirective
 from sphinxcontrib.bibtex.transforms import BibliographyTransform
-import six
 
 
 logger = sphinx.util.logging.getLogger(__name__)
@@ -57,12 +56,9 @@ def process_citations(app, doctree, docname):
     :type docname: :class:`str`
     """
     for node in doctree.traverse(docutils.nodes.citation):
-        key = node[0].astext()
-        try:
+        if "bibtex" in node.attributes.get('classes', []):
+            key = node[0].astext()
             label = app.env.bibtex_cache.get_label_from_key(key)
-        except KeyError:
-            logger.warning("could not relabel citation [%s]" % key)
-        else:
             node[0] = docutils.nodes.label('', label)
 
 
@@ -79,20 +75,11 @@ def process_citation_references(app, doctree, docname):
     # sphinx has already turned citation_reference nodes
     # into reference nodes, so iterate over reference nodes
     for node in doctree.traverse(docutils.nodes.reference):
-        # exclude sphinx [source] labels
-        if isinstance(node[0], docutils.nodes.Element):
-            if 'viewcode-link' in node[0]['classes']:
-                continue
-        text = node[0].astext()
-        if text.startswith('[') and text.endswith(']'):
+        if "bibtex" in node.attributes.get('classes', []):
+            text = node[0].astext()
             key = text[1:-1]
-            try:
-                label = app.env.bibtex_cache.get_label_from_key(key)
-            except KeyError:
-                logger.warning(
-                    "could not relabel citation reference [%s]" % key)
-            else:
-                node[0] = docutils.nodes.Text('[' + label + ']')
+            label = app.env.bibtex_cache.get_label_from_key(key)
+            node[0] = docutils.nodes.Text('[' + label + ']')
 
 
 def check_duplicate_labels(app, env):
@@ -105,7 +92,7 @@ def check_duplicate_labels(app, env):
     """
     label_to_key = {}
     for info in env.bibtex_cache.get_all_bibliography_caches():
-        for key, label in six.iteritems(info.labels):
+        for key, label in info.labels.items():
             if label in label_to_key:
                 logger.warning(
                     "duplicate label for keys %s and %s"
@@ -143,13 +130,8 @@ def setup(app):
         app.add_directive("bibliography", BibliographyDirective)
         app.add_role("cite", CiteRole())
         app.add_node(bibliography, override=True)
-    else:
-        assert _directives["bibliography"] is BibliographyDirective
-    try:
-        transforms = app.registry.get_transforms()
-    except AttributeError:  # Sphinx < 1.7
-        from sphinx.io import SphinxStandaloneReader
-        transforms = SphinxStandaloneReader.transforms
+    assert _directives["bibliography"] is BibliographyDirective
+    transforms = app.registry.get_transforms()
     if BibliographyTransform not in transforms:
         app.add_transform(BibliographyTransform)
 
